@@ -14,8 +14,8 @@ from unogenerator.reusing.currency import Currency
 from unogenerator.reusing.percentage import Percentage
 from time import sleep
 
-__version__ = '0.27.0'
-__versiondatetime__=datetime(2022, 8, 19, 8, 55)
+__version__ = '0.29.0'
+__versiondatetime__=datetime(2022, 9, 4, 8, 29)
 __versiondate__=__versiondatetime__.date()
 
 try:
@@ -619,7 +619,7 @@ def bytes_after_trim_image(filename_or_bytessequence, type):
             filename_to_trim=filename_or_bytessequence
 
         #Trims white space
-        p=run(f"convert -trim '{filename_to_trim}' '{filename_trimed}'",  shell=True)
+        p=run(f"convert -trim +repage '{filename_to_trim}' '{filename_trimed}'",  shell=True)
         if p.returncode==0:
             #Alter bytes if converted
             with open(filename_trimed, "r+b") as f:
