@@ -15,7 +15,7 @@ from unogenerator.commons import __version__, addDebugSystem, argparse_epilog, C
 from unogenerator.reusing.currency import Currency
 from unogenerator.reusing.percentage import Percentage
 from unogenerator.unogenerator import ODT_Standard, ODS_Standard
-from unogenerator.helpers import helper_title_values_total_row,helper_title_values_total_column, helper_totals_row, helper_totals_from_range, helper_list_of_ordereddicts, helper_list_of_dicts, helper_list_of_ordereddicts_with_totals, helper_ods_sheet_stylenames
+from unogenerator.helpers import helper_title_values_total_row,helper_title_values_total_column, helper_totals_row, helper_totals_from_range, helper_list_of_ordereddicts, helper_list_of_dicts, helper_list_of_ordereddicts_with_totals, helper_ods_sheet_stylenames, helper_split_big_listofrows
 from os import remove
 from tqdm import tqdm
 
@@ -244,6 +244,14 @@ def demo_ods_standard(language, port=2002, suffix="",):
         doc.sortRange("B2:B10",  0)
         doc.sortRange("C2:C10",  0, False)
         
+        ## Split big LOR
+        lor=[]
+        for i in range(1000):
+            lor.append([i, _("String")+" "+ str(i), datetime.now()])
+            
+        helper_split_big_listofrows(doc, "Splits in 400 rows", lor, ["Integer", "String", "Datetime"], columns_width=[2, 5, 5],  max_rows=400)
+
+        
         ## Sheet with all styles names
         helper_ods_sheet_stylenames(doc)
         doc.statistics.ods_sheet_statistics()
